<?php

/**
 * Page de fonctions permettant la gestion des alias virtuels.
 */

require_once ($_SERVER["DOCUMENT_ROOT"]."/services/bdd/connexion.php");
require_once ($_SERVER["DOCUMENT_ROOT"]."/services/utilisateurs/privileges.php");

/**
 * Fonction listant les alias virtuels.
 */
function listeAliasVirtuelsPostfix($pdo) {
	try {
		// Filtre des alias virtuels de l'utilisateur courant
		$req = $pdo->query('SELECT * FROM postfix_alias_virtuels WHERE destination='."\"$_SESSION[pseudo_utilisateur]\"");
		$liste_alias_virtuels = array();
		foreach ($req as $alias_virtuels_bdd => $alias_virtuels) {
			array_push($liste_alias_virtuels,$alias_virtuels);
		}
		return $liste_alias_virtuels;
	}
	catch (\Exception $e) {
		die ("Erreur de requête de selection des alias virtuels : ".$e->getMessage());
	}
}

/**
 * Fonction d'ajout d'un alias virtuel.
 */
function ajoutAliasVirtuelsPostfix($pdo) {
	try {
		// Insertion de l'alias virtuel entré par l'utilisateur et lié avec son adresse
		$req='INSERT INTO postfix_alias_virtuels (courriel,destination,active) VALUES (:alias_virtuel,:courriel,1)';
		
		$sql=$pdo->prepare($req);
		$sql->bindValue(':courriel',$_SESSION['pseudo_utilisateur']);
		
		// Si l'utilisateur spécifie un préfixe à son alias, un "." est ajouté pour lé séparé du reste afin d'avoir "préfixe.alias@NdD"
		if (!empty($_POST['prefix_alias'])) {
			$separateur_prefix_alias=".";
		}
		// Permet de ne pas renvoyer le message "Notice: Undefined variable: separateur_prefix_alias" lors de lexécution du "bindValue" suivant
		else {
			$separateur_prefix_alias="";
		}
		
		$sql->bindValue(':alias_virtuel',$_POST['prefix_alias'].$separateur_prefix_alias.$_POST['nom_alias']."@".$_POST['choix_domaine_alias']);
		$sql->execute();
		
		if($sql->rowCount() == 1){
			return true;
		}
		
		else{
			return false;
		}
	}
	catch (\Exception $e) {
		// Récupération du code de retour de la commande SQLite.
		$code_retour=$sql->errorInfo();
		
		if ($code_retour[0]=="23000") {
			// Code de retour envoyé par le pilote PDO SQLite signifiant que la contrainte "UNIQUE" du champ "courriel" de la table "postif_alias_virtuels" est violé. L'alias envoyé via le formulaire par l'utilisateur a déjà été renseigné
			header ("Location: /pages/gestion/administration.php?page=alias&erreur=3");
			die();
		}
		elseif ($code_retour[0]=="HY000") {
			// Code de retour envoyé par le pilote PDO SQLite lorsque la base est accessible en lecture seule à www-data
			header ("Location: /pages/gestion/administration.php?page=alias&erreur=4");
			die();
		}
		else {
			// En cas d'erreur non gérée, le script s'arrête avec un message d'erreur à destination de l'administrateur du serveur
			die ("Erreur de requête d'ajout d'alias virtuel : ".$e->getMessage());
		}
	}
}

/**
 * Fonction d'activation/désactivation d'un alias virtuel.
 * Suite à une soumission du formulaire dédié, cette fonction va traiter l'ensemble des alias d'un utilisateur.
 * Elle occasionnera peut-être des baisses de performance si un très grand nombre d'alias existe pour un utilisateur donné (le traitement n'intervenant pas spécifiquement pour l'entrée modifiée).
 */
function modifEtatAliasVirtuelsPostfix($pdo) {
	try {
		$compteModifs=0;
		foreach ($_POST as $id_alias_virtuel => $etat_alias_virtuel) {
			$req='UPDATE postfix_alias_virtuels SET active=:etat_alias_virtuel WHERE id=:id_alias_virtuel AND destination=:pseudo_utilisateur';
			
			$sql=$pdo->prepare($req);
			$sql->bindValue(':etat_alias_virtuel',$etat_alias_virtuel);
			$sql->bindValue(':id_alias_virtuel',$id_alias_virtuel);
			$sql->bindValue(':pseudo_utilisateur',$_SESSION['pseudo_utilisateur']);
			$sql->execute();
		}
	}
	catch (\Exception $e) {
		// Récupération du code de retour de la commande SQLite.
		$code_retour=$sql->errorInfo();
		
		if ($code_retour[0]=="HY000") {
			// Code de retour envoyé par le pilote PDO SQLite lorsque la base est accessible en lecture seule à www-data
			header ("Location: /pages/gestion/administration.php?page=alias&erreur=4");
			die();
		}
		else {
			// En cas d'erreur non gérée, le script s'arrête avec un message d'erreur à destination de l'administrateur du serveur
			die ("Erreur de requête de modification d'état pour les alias virtuels : ".$e->getMessage());
		}
	}
}

/**
 * Fonction de suppression d'un alias virtuel.
 */
function supprAliasVirtuelsPostfix($pdo) {
	try {
		//$req = $pdo->query('DELETE FROM postfix_alias_virtuels WHERE id='."$_GET[supprAliasVirtuel]".' AND courriel='."\"$_SESSION[pseudo_utilisateur]".'@"'.'||(SELECT domaine FROM postfix_domaines WHERE defaut=1)');
		$req='DELETE FROM postfix_alias_virtuels WHERE id=:id_alias_virtuel AND destination=:pseudo_utilisateur';
		//$req='DELETE FROM postfix_alias_virtuels WHERE id=:id_alias_virtuel AND courriel=:pseudo_utilisateur||(SELECT domaine FROM postfix_domaines WHERE defaut=1)';
		$sql=$pdo->prepare($req);
		//$sql->bindParam(':id',$_GET['supprAliasVirtuel'],':pseudo_utilisateur',$_SESSION['pseudo_utilisateur]',':@','@');
		$sql->bindValue(':id_alias_virtuel',$_GET['supprAliasVirtuel']);
		//$sql->bindValue(':pseudo_utilisateur',$_SESSION['pseudo_utilisateur']."@");
		$sql->bindValue(':pseudo_utilisateur',$_SESSION['pseudo_utilisateur']);
		$sql->execute();
		if($sql->rowCount() == 1){
			return true;
		}
		else{
			return false;
		}
	}
	catch (\Exception $e) {
		// Récupération du code de retour de la commande SQLite.
		$code_retour=$sql->errorInfo();
		
		if ($code_retour[0]=="HY000") {
			// Code de retour envoyé par le pilote PDO SQLite lorsque la base est accessible en lecture seule à www-data
			header ("Location: /pages/gestion/administration.php?page=alias&erreur=4");
			die();
		}
		else {
			// En cas d'erreur non gérée, le script s'arrête avec un message d'erreur à destination de l'administrateur du serveur
			die ("Erreur de requête de suppression d'un alias virtuel : ".$e->getMessage());
		}
	}
}

?>